Struct swc_ecma_parser::StringInput [−][src]
pub struct StringInput<'a> { /* fields omitted */ }Expand description
Implementation of Input.
Implementations
start and end can be arbitrary value, but start should be less than
or equal to end.
swc get this value from [SourceMap] because code generator depends on
some methods of [SourceMap].
If you are not going to use methods from
[SourceMap], you may use any value.